==> owncloud-8.1.0p2.tgz: owncloud/apps/files_sharing/l10n/et_EE.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Serverist serverisse jagamine pole antud serveris lubatud",
    "The mountpoint name contains invalid characters." : "Ühenduspunkti nimes on vigaseid märke.",
    "Invalid or untrusted SSL certificate" : "Vigane või tundmatu SSL sertifikaat",
    "Couldn't add remote share" : "Ei suutnud lisada kaugjagamist",
    "Shared with you" : "Sinuga jagatud",
    "Shared with others" : "Teistega jagatud",
    "Shared by link" : "Jagatud lingiga",
    "Nothing shared with you yet" : "Sinuga pole veel midagi jagatud",
    "Nothing shared yet" : "Midagi pole veel jagatud",
    "No shared links" : "Jagatud linke pole",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Soovid lisata kaugjagamise {name} asukohast {owner}@{remote}?",
    "Remote share" : "Kaugjagamine",
    "Remote share password" : "Kaugjagamise parool",
    "Cancel" : "Loobu",
    "Add remote share" : "Lisa kaugjagamine",
    "You can upload into this folder" : "Sa saad sellesse kausta faile üles laadida",
    "Invalid ownCloud url" : "Vigane ownCloud url",
    "Share" : "Jaga",
    "Shared by" : "Jagas",
    "A file or folder has been <strong>shared</strong>" : "Fail või kataloog on <strong>jagatud</strong>",
    "You shared %1$s with %2$s" : "Jagasid %1$s  %2$s kasutajaga",
    "You shared %1$s with group %2$s" : "Jagasid %1$s %2$s grupiga",
    "%2$s shared %1$s with you" : "%2$s jagas sinuga %1$s",
    "You shared %1$s via link" : "Jagasid %1$s lingiga",
    "Shares" : "Jagamised",
    "This share is password-protected" : "See jagamine on parooliga kaitstud",
    "The password is wrong. Try again." : "Parool on vale. Proovi uuesti.",
    "Password" : "Parool",
    "No entries found in this folder" : "Selles kaustas ei leitud kirjeid",
    "Name" : "Nimi",
    "Share time" : "Jagamise aeg",
    "Sorry, this link doesn’t seem to work anymore." : "Vabandust, see link ei tundu enam toimivat.",
    "Reasons might be:" : "Põhjused võivad olla:",
    "the item was removed" : "üksus on eemaldatud",
    "the link expired" : "link on aegunud",
    "sharing is disabled" : "jagamine on peatatud",
    "For more info, please ask the person who sent this link." : "Täpsema info saamiseks palun pöördu lingi saatnud isiku poole.",
    "Add to your ownCloud" : "Lisa oma ownCloudi",
    "Download" : "Lae alla",
    "Download %s" : "Laadi alla %s",
    "Direct link" : "Otsene link",
    "Open documentation" : "Ava dokumentatsioon",
    "Allow users on this server to send shares to other servers" : "Luba selle serveri kasutajatel saata faile teistesse serveritesse",
    "Allow users on this server to receive shares from other servers" : "Luba selle serveri kasutajatel võtta vastu jagamisi teistest serveritest",
    "Share it:" : "Jaga seda:",
    "Add it to your website:" : "Lisa see oma veebisaidile:",
    "Share with me via ownCloud" : "Jaga minuga läbi ownCloudiga",
    "HTML Code:" : "HTML kood:"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-8.2.2p3.tgz: owncloud/apps/files_sharing/l10n/et_EE.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Serverist serverisse jagamine pole antud serveris lubatud",
    "The mountpoint name contains invalid characters." : "Ühenduspunkti nimes on vigaseid märke.",
    "Invalid or untrusted SSL certificate" : "Vigane või tundmatu SSL sertifikaat",
    "Storage not valid" : "Andmehoidla pole korrektne",
    "Couldn't add remote share" : "Ei suutnud lisada kaugjagamist",
    "Shared with you" : "Sinuga jagatud",
    "Shared with others" : "Teistega jagatud",
    "Shared by link" : "Jagatud lingiga",
    "Nothing shared with you yet" : "Sinuga pole veel midagi jagatud",
    "Files and folders others share with you will show up here" : "Siin näidatakse faile ja kaustasid, mida teised on sulle jaganud",
    "Nothing shared yet" : "Midagi pole veel jagatud",
    "Files and folders you share will show up here" : "Siin kuvatakse faile ja kaustasid, mida sa oled teistega jaganud",
    "No shared links" : "Jagatud linke pole",
    "Files and folders you share by link will show up here" : "Siin kuvatakse faile ja kaustasid, mida sa jagad lingiga",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Soovid lisata kaugjagamise {name} asukohast {owner}@{remote}?",
    "Remote share" : "Kaugjagamine",
    "Remote share password" : "Kaugjagamise parool",
    "Cancel" : "Loobu",
    "Add remote share" : "Lisa kaugjagamine",
    "You can upload into this folder" : "Sa saad sellesse kausta faile üles laadida",
    "No ownCloud installation (7 or higher) found at {remote}" : "Saidilt {remote} ei leitud ownCloudi (7 või uuem) ",
    "Invalid ownCloud url" : "Vigane ownCloud url",
    "Shared by" : "Jagas",
    "Sharing" : "Jagamine",
    "A file or folder has been <strong>shared</strong>" : "Fail või kataloog on <strong>jagatud</strong>",
    "You shared %1$s with %2$s" : "Jagasid %1$s  %2$s kasutajaga",
    "You shared %1$s with group %2$s" : "Jagasid %1$s %2$s grupiga",
    "%2$s shared %1$s with you" : "%2$s jagas sinuga %1$s",
    "You shared %1$s via link" : "Jagasid %1$s lingiga",
    "Shares" : "Jagamised",
    "Accept" : "Nõustu",
    "Decline" : "Lükka tagasi",
    "This share is password-protected" : "See jagamine on parooliga kaitstud",
    "The password is wrong. Try again." : "Parool on vale. Proovi uuesti.",
    "Password" : "Parool",
    "No entries found in this folder" : "Selles kaustas ei leitud kirjeid",
    "Name" : "Nimi",
    "Share time" : "Jagamise aeg",
    "Sorry, this link doesn’t seem to work anymore." : "Vabandust, see link ei tundu enam toimivat.",
    "Reasons might be:" : "Põhjused võivad olla:",
    "the item was removed" : "üksus on eemaldatud",
    "the link expired" : "link on aegunud",
    "sharing is disabled" : "jagamine on peatatud",
    "For more info, please ask the person who sent this link." : "Täpsema info saamiseks palun pöördu lingi saatnud isiku poole.",
    "Add to your ownCloud" : "Lisa oma ownCloudi",
    "Download" : "Lae alla",
    "Download %s" : "Laadi alla %s",
    "Direct link" : "Otsene link",
    "Open documentation" : "Ava dokumentatsioon",
    "Allow users on this server to send shares to other servers" : "Luba selle serveri kasutajatel saata faile teistesse serveritesse",
    "Allow users on this server to receive shares from other servers" : "Luba selle serveri kasutajatel võtta vastu jagamisi teistest serveritest",
    "Share it:" : "Jaga seda:",
    "Add to your website" : "Lisa oma veebisaidile",
    "Share with me via ownCloud" : "Jaga minuga läbi ownCloudiga",
    "HTML Code:" : "HTML kood:"
},
"nplurals=2; plural=(n != 1);");
